package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.CmsAlbumMaterial;
import com.ruoyi.system.domain.CmsMaterial;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.CmsAlbum;
import com.ruoyi.system.service.ICmsAlbumService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 相册管理Controller
 *
 * @author libao
 * @date 2024-05-09
 */
@RestController
@RequestMapping("/system/album")
public class CmsAlbumController extends BaseController
{
    @Autowired
    private ICmsAlbumService cmsAlbumService;

    /**
     * 查询相册管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:album:list')")
    @GetMapping("/list")
    public TableDataInfo list(CmsAlbum cmsAlbum)
    {
        startPage();
        List<CmsAlbum> list = cmsAlbumService.selectCmsAlbumList(cmsAlbum);
        return getDataTable(list);
    }

    /**
     * 查询相册关联素材管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:album:list')")
    @GetMapping("/materialList")
    public TableDataInfo materialList(CmsMaterial material)
    {
        startPage();
        List<CmsAlbumMaterial> list = cmsAlbumService.selectAlbumMaterialList(material);
        return getDataTable(list);
    }
    /**
     * 保存素材
     */
    @PostMapping( "/saveMaterial")
    @ResponseBody
    public AjaxResult saveMaterial(@RequestBody CmsMaterial material)
    {
        if(StringUtils.isEmpty(material.getAlbumId())|| StringUtils.isEmpty(material.getMaterialIds())){
            return AjaxResult.error("参数传递错误!");
        }
        cmsAlbumService.saveMaterial(material.getAlbumId(),material.getMaterialIds());
        return success();
    }
    /**
     * 删除专辑关联的素材
     */
    @Log(title = "相册管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/deleteMaterials/{ids}")
    public AjaxResult deleteMaterialBatch(@PathVariable String ids)
    {
        if(StringUtils.isEmpty(ids)){
            return AjaxResult.error("参数传递错误!");
        }
        cmsAlbumService.deleteMaterialBatch(ids);
        return success();
    }
//    /**
//     * 删除相册管理
//     */
//    @PreAuthorize("@ss.hasPermi('system:album:remove')")
//    @Log(title = "相册管理", businessType = BusinessType.DELETE)
//    @DeleteMapping("/{albumIds}")
//    public AjaxResult remove(@PathVariable String[] albumIds)
//    {
//        return toAjax(cmsAlbumService.deleteCmsAlbumByAlbumIds(albumIds));
//    }

    /**
     * 导出相册管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:album:export')")
    @Log(title = "相册管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmsAlbum cmsAlbum)
    {
        List<CmsAlbum> list = cmsAlbumService.selectCmsAlbumList(cmsAlbum);
        ExcelUtil<CmsAlbum> util = new ExcelUtil<CmsAlbum>(CmsAlbum.class);
        util.exportExcel(response, list, "相册管理数据");
    }

    /**
     * 获取相册管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:album:query')")
    @GetMapping(value = "/{albumId}")
    public AjaxResult getInfo(@PathVariable("albumId") String albumId)
    {
        return success(cmsAlbumService.selectCmsAlbumByAlbumId(albumId));
    }

    /**
     * 新增相册管理
     */
    @PreAuthorize("@ss.hasPermi('system:album:add')")
    @Log(title = "相册管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmsAlbum cmsAlbum)
    {
        return toAjax(cmsAlbumService.insertCmsAlbum(cmsAlbum));
    }

    /**
     * 修改相册管理
     */
    @PreAuthorize("@ss.hasPermi('system:album:edit')")
    @Log(title = "相册管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmsAlbum cmsAlbum)
    {
        return toAjax(cmsAlbumService.updateCmsAlbum(cmsAlbum));
    }

    /**
     * 删除相册管理
     */
    @PreAuthorize("@ss.hasPermi('system:album:remove')")
    @Log(title = "相册管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{albumIds}")
    public AjaxResult remove(@PathVariable String[] albumIds)
    {
        return toAjax(cmsAlbumService.deleteCmsAlbumByAlbumIds(albumIds));
    }
}
