package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.CmsAlbumMaterial;
import com.ruoyi.system.service.ICmsAlbumMaterialService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 相册关联素材表Controller
 *
 * @author libao
 * @date 2024-05-11
 */
@RestController
@RequestMapping("/system/albumMaterial")
public class CmsAlbumMaterialController extends BaseController
{
    @Autowired
    private ICmsAlbumMaterialService cmsAlbumMaterialService;

    /**
     * 查询相册关联素材表列表
     */
    @PreAuthorize("@ss.hasPermi('system:albumMaterial:list')")
    @GetMapping("/list")
    public TableDataInfo list(CmsAlbumMaterial cmsAlbumMaterial)
    {
        startPage();
        List<CmsAlbumMaterial> list = cmsAlbumMaterialService.selectCmsAlbumMaterialList(cmsAlbumMaterial);
        return getDataTable(list);
    }

    /**
     * 导出相册关联素材表列表
     */
    @PreAuthorize("@ss.hasPermi('system:albumMaterial:export')")
    @Log(title = "相册关联素材表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmsAlbumMaterial cmsAlbumMaterial)
    {
        List<CmsAlbumMaterial> list = cmsAlbumMaterialService.selectCmsAlbumMaterialList(cmsAlbumMaterial);
        ExcelUtil<CmsAlbumMaterial> util = new ExcelUtil<CmsAlbumMaterial>(CmsAlbumMaterial.class);
        util.exportExcel(response, list, "相册关联素材表数据");
    }

    /**
     * 获取相册关联素材表详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:albumMaterial:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(cmsAlbumMaterialService.selectCmsAlbumMaterialById(id));
    }

    /**
     * 新增相册关联素材表
     */
    @PreAuthorize("@ss.hasPermi('system:albumMaterial:add')")
    @Log(title = "相册关联素材表", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmsAlbumMaterial cmsAlbumMaterial)
    {
        return toAjax(cmsAlbumMaterialService.insertCmsAlbumMaterial(cmsAlbumMaterial));
    }

    /**
     * 修改相册关联素材表
     */
    @PreAuthorize("@ss.hasPermi('system:albumMaterial:edit')")
    @Log(title = "相册关联素材表", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmsAlbumMaterial cmsAlbumMaterial)
    {
        return toAjax(cmsAlbumMaterialService.updateCmsAlbumMaterial(cmsAlbumMaterial));
    }

    /**
     * 删除相册关联素材表
     */
    @PreAuthorize("@ss.hasPermi('system:albumMaterial:remove')")
    @Log(title = "相册关联素材表", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(cmsAlbumMaterialService.deleteCmsAlbumMaterialByIds(ids));
    }
}
