package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.CmsMaterialUse;
import com.ruoyi.system.service.ICmsMaterialUseService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 素材使用记录Controller
 *
 * @author libao
 * @date 2024-05-09
 */
@RestController
@RequestMapping("/system/materialUse")
public class CmsMaterialUseController extends BaseController
{
    @Autowired
    private ICmsMaterialUseService cmsMaterialUseService;

    /**
     * 查询素材使用记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:materialUse:list')")
    @GetMapping("/list")
    public TableDataInfo list(CmsMaterialUse cmsMaterialUse)
    {
        startPage();
        List<CmsMaterialUse> list = cmsMaterialUseService.selectCmsMaterialUseList(cmsMaterialUse);
        return getDataTable(list);
    }

    /**
     * 导出素材使用记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:materialUse:export')")
    @Log(title = "素材使用记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmsMaterialUse cmsMaterialUse)
    {
        List<CmsMaterialUse> list = cmsMaterialUseService.selectCmsMaterialUseList(cmsMaterialUse);
        ExcelUtil<CmsMaterialUse> util = new ExcelUtil<CmsMaterialUse>(CmsMaterialUse.class);
        util.exportExcel(response, list, "素材使用记录数据");
    }

    /**
     * 获取素材使用记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:materialUse:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(cmsMaterialUseService.selectCmsMaterialUseById(id));
    }

    /**
     * 新增素材使用记录
     */
    @PreAuthorize("@ss.hasPermi('system:materialUse:add')")
    @Log(title = "素材使用记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmsMaterialUse cmsMaterialUse)
    {
        return toAjax(cmsMaterialUseService.insertCmsMaterialUse(cmsMaterialUse));
    }

    /**
     * 修改素材使用记录
     */
    @PreAuthorize("@ss.hasPermi('system:materialUse:edit')")
    @Log(title = "素材使用记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmsMaterialUse cmsMaterialUse)
    {
        return toAjax(cmsMaterialUseService.updateCmsMaterialUse(cmsMaterialUse));
    }

    /**
     * 删除素材使用记录
     */
    @PreAuthorize("@ss.hasPermi('system:materialUse:remove')")
    @Log(title = "素材使用记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(cmsMaterialUseService.deleteCmsMaterialUseByIds(ids));
    }
}
