package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.CmsTags;
import com.ruoyi.system.service.ICmsTagsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 语言标签管理Controller
 *
 * @author libao
 * @date 2024-05-09
 */
@RestController
@RequestMapping("/system/tags")
public class CmsTagsController extends BaseController
{
    @Autowired
    private ICmsTagsService cmsTagsService;

    /**
     * 查询语言标签管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:tags:list')")
    @GetMapping("/list")
    public TableDataInfo list(CmsTags cmsTags)
    {
//        startPage();
        List<CmsTags> list = cmsTagsService.selectCmsTagsList(cmsTags);
        return getDataTable(list);
    }

    /**
     * 导出语言标签管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:tags:export')")
    @Log(title = "语言标签管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmsTags cmsTags)
    {
        List<CmsTags> list = cmsTagsService.selectCmsTagsList(cmsTags);
        ExcelUtil<CmsTags> util = new ExcelUtil<CmsTags>(CmsTags.class);
        util.exportExcel(response, list, "语言标签管理数据");
    }

    /**
     * 获取语言标签管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:tags:query')")
    @GetMapping(value = "/{tagId}")
    public AjaxResult getInfo(@PathVariable("tagId") Long tagId)
    {
        return success(cmsTagsService.selectCmsTagsByTagId(tagId));
    }

    /**
     * 新增语言标签管理
     */
    @PreAuthorize("@ss.hasPermi('system:tags:add')")
    @Log(title = "语言标签管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmsTags cmsTags)
    {
        return toAjax(cmsTagsService.insertCmsTags(cmsTags));
    }

    /**
     * 修改语言标签管理
     */
    @PreAuthorize("@ss.hasPermi('system:tags:edit')")
    @Log(title = "语言标签管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmsTags cmsTags)
    {
        return toAjax(cmsTagsService.updateCmsTags(cmsTags));
    }

    /**
     * 删除语言标签管理
     */
    @PreAuthorize("@ss.hasPermi('system:tags:remove')")
    @Log(title = "语言标签管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{tagIds}")
    public AjaxResult remove(@PathVariable Long[] tagIds)
    {
        return toAjax(cmsTagsService.deleteCmsTagsByTagIds(tagIds));
    }
}
