package com.ruoyi.system.service.impl;

import java.util.Date;
import java.util.List;

import com.google.common.collect.Lists;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.Guid;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.domain.CmsAlbumMaterial;
import com.ruoyi.system.domain.CmsMaterial;
import com.ruoyi.system.domain.CmsMaterialUse;
import com.ruoyi.system.mapper.CmsMaterialMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.CmsAlbumMapper;
import com.ruoyi.system.domain.CmsAlbum;
import com.ruoyi.system.service.ICmsAlbumService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 相册管理Service业务层处理
 *
 * @author libao
 * @date 2024-05-09
 */
@Service
public class CmsAlbumServiceImpl implements ICmsAlbumService
{
    @Autowired
    private CmsAlbumMapper cmsAlbumMapper;
    @Autowired
    private CmsMaterialMapper cmsMaterialMapper;

    /**
     * 查询相册管理
     *
     * @param albumId 相册管理主键
     * @return 相册管理
     */
    @Override
    public CmsAlbum selectCmsAlbumByAlbumId(String albumId)
    {
        return cmsAlbumMapper.selectCmsAlbumByAlbumId(albumId);
    }

    /**
     * 查询相册管理列表
     *
     * @param cmsAlbum 相册管理
     * @return 相册管理
     */
    @Override
    public List<CmsAlbum> selectCmsAlbumList(CmsAlbum cmsAlbum)
    {
        return cmsAlbumMapper.selectCmsAlbumList(cmsAlbum);
    }

    /**
     * 新增相册管理
     *
     * @param cmsAlbum 相册管理
     * @return 结果
     */
    @Override
    public int insertCmsAlbum(CmsAlbum cmsAlbum)
    {
        cmsAlbum.setAlbumId(Guid.get());
        cmsAlbum.setCreateTime(DateUtils.getNowDate());
        return cmsAlbumMapper.insertCmsAlbum(cmsAlbum);
    }

    /**
     * 修改相册管理
     *
     * @param cmsAlbum 相册管理
     * @return 结果
     */
    @Override
    public int updateCmsAlbum(CmsAlbum cmsAlbum)
    {
        return cmsAlbumMapper.updateCmsAlbum(cmsAlbum);
    }

    /**
     * 批量删除相册管理
     *
     * @param albumIds 需要删除的相册管理主键
     * @return 结果
     */
    @Override
    public int deleteCmsAlbumByAlbumIds(String[] albumIds)
    {
        return cmsAlbumMapper.deleteCmsAlbumByAlbumIds(albumIds);
    }

    /**
     * 删除相册管理信息
     *
     * @param albumId 相册管理主键
     * @return 结果
     */
    @Override
    public int deleteCmsAlbumByAlbumId(String albumId)
    {
        return cmsAlbumMapper.deleteCmsAlbumByAlbumId(albumId);
    }

    @Override
    public List<CmsAlbumMaterial> selectAlbumMaterialList(CmsMaterial material) {
        return cmsMaterialMapper.selectAlbumMaterialList(material);
    }


    /**
     * 保存专辑关联的素材
     * @param albumId
     * @param materialIds
     */
    @Override
    @Transactional
    public void saveMaterial(String albumId, String materialIds) {
        String[] addArr= Convert.toStrArray(materialIds);

        SysUser user= SecurityUtils.getLoginUser().getUser();

        if(addArr!=null&&addArr.length>0){
            List<CmsAlbumMaterial> list= Lists.newArrayList();
            CmsAlbumMaterial albumMaterial=null;
            Integer i=0;
            for(String s:addArr){
                i++;
                albumMaterial=new CmsAlbumMaterial();
                albumMaterial.setAlbumId(albumId);
                albumMaterial.setMaterialId(s);
                albumMaterial.setSort(i);
                list.add(albumMaterial);
            }
            cmsAlbumMapper.insertAlbumMaterialBatch(list);

            //插入使用记录 cms_material_use
            List<CmsMaterialUse> useList=Lists.newArrayList();
            CmsMaterialUse use=null;
            for(String s:addArr){
                use=new CmsMaterialUse();
                use.setUseId(albumId);
                use.setMaterialId(s);
                use.setUserId(user.getUserId().toString());
                use.setCreateBy(user.getUserName());
                use.setCreateTime(new Date());
                use.setUseTable("cms_album_material");
                use.setUseColumn("album_id");
                useList.add(use);
            }
            cmsMaterialMapper.insertMaterialUseBatch(useList);

            //更新素材使用状态
            for(String mid:addArr){
                cmsMaterialMapper.updateMaterialUseState(mid, "1");
            }
        }

    }

    /**
     * 删除专辑关联的素材
     * @param ids
     */
    @Override
    @Transactional
    public void deleteMaterialBatch(String ids) {
        String[] arr= Convert.toStrArray(ids);
        //删除使用记录
        List<CmsAlbumMaterial> albumMaterials = cmsAlbumMapper.selectAlbumMaterialByIds(arr);
        for(CmsAlbumMaterial albumMaterial:albumMaterials){
            cmsMaterialMapper.deleteMaterialUseByMx(albumMaterial.getMaterialId(),"cms_album_material",albumMaterial.getAlbumId(),"album_id");
            int n=cmsMaterialMapper.selectCountMaterialUse(albumMaterial.getMaterialId());
            if(n==0){
                cmsMaterialMapper.updateMaterialUseState(albumMaterial.getMaterialId(), "0");
            }
        }
        cmsAlbumMapper.deleteAlbumMaterialByIds(arr);
    }
}
