package com.ruoyi.system.service.impl;

import java.text.SimpleDateFormat;
import java.util.*;

import cn.hutool.cache.Cache;
import cn.hutool.cache.CacheUtil;
import com.google.common.collect.Lists;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.CmsArticleContent;
import com.ruoyi.system.domain.CmsCategory;
import com.ruoyi.system.domain.CmsTags;
import com.ruoyi.system.mapper.CmsArticleContentMapper;
import com.ruoyi.system.mapper.CmsTagsMapper;
import com.ruoyi.system.service.ICmsCategoryService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.CmsArticleMapper;
import com.ruoyi.system.domain.CmsArticle;
import com.ruoyi.system.service.ICmsArticleService;

/**
 * 文章管理Service业务层处理
 *
 * @author libao
 * @date 2024-05-09
 */
@Service
public class CmsArticleServiceImpl implements ICmsArticleService
{
    @Autowired
    private CmsArticleMapper cmsArticleMapper;
    @Autowired
    private CmsArticleContentMapper contentMapper;
    @Autowired
    private ICmsCategoryService categoryService;
    @Autowired
    private CmsTagsMapper tagsMapper;

    private Cache<String, CmsCategory> categoryCache= CacheUtil.newLFUCache(100);
    private Cache<String, CmsTags> tagCache= CacheUtil.newLFUCache(100);

    /**
     * 查询文章管理
     *
     * @param id 文章管理主键
     * @return 文章管理
     */
    @Override
    public CmsArticle selectCmsArticleById(Long id)
    {
        CmsArticle article=cmsArticleMapper.selectCmsArticleById(id);
        Map<String, Object> m = cmsArticleMapper.getArticleContent(String.valueOf(id));
        if(m!=null){
            article.setContent(String.valueOf(m.get("content")));
            article.setContent_markdown_source(String.valueOf(m.get("content_markdown_source")));
        }
        selectCategory(article);
        selectTags(article);
        return article;
    }

    /**
     * 查询文章管理列表
     *
     * @param cmsArticle 文章管理
     * @return 文章管理
     */
    @Override
    public List<CmsArticle> selectCmsArticleList(CmsArticle cmsArticle)
    {
        List<CmsArticle> articles=cmsArticleMapper.selectCmsArticleList(cmsArticle);
        selectTags(articles);
        selectCategory(articles);
        return articles;
    }
    private void selectCategory(List<CmsArticle> list){
        list.forEach(a->{
            String cid = a.getCategoryId();
            CmsCategory category=categoryCache.get(cid);
            if(category==null){
                category=categoryService.selectCmsCategoryByCategoryId(Long.valueOf(cid));
                if(category!=null){
                    categoryCache.put(cid,category);
                }
            }
            if(category!=null){
                a.setCategory(category);
            }
        });
    }
    private void selectCategory(CmsArticle a){

        String cid = a.getCategoryId();
        CmsCategory category=categoryCache.get(cid);
        if(category==null){
            category=categoryService.selectCmsCategoryByCategoryId(Long.valueOf(cid));
            if(category!=null){
                categoryCache.put(cid,category);
            }
        }
        if(category!=null){
            a.setCategory(category);
        }
    }
    private void selectTags(List<CmsArticle> articles) {
        // 转换标签名称，这部分可以使用缓存提升性能
        articles.forEach(a -> {
            String tagsStr = a.getTags();
            if (StringUtils.isNotEmpty(tagsStr)) {
                String[] tagsArr = Convert.toStrArray(tagsStr);
                List<CmsTags> tags = new ArrayList<>();
                for (String id : tagsArr) {
                    if (StringUtils.isNotEmpty(id)) {
                        CmsTags tag = tagCache.get(id);
                        if (tag == null) {
                            tag = tagsMapper.selectCmsTagsByTagId(Long.valueOf(id));
                            tagCache.put(id, tag);
                        }
                        tags.add(tag);
                    }
                }
                a.setTagList(tags);
                // 清除逗号分隔符后将原始的tags值存入tags_name字段
                a.setTags_name(Arrays.toString(tagsArr));
            }
        });
    }
    private void selectTags(CmsArticle a){
        String tids = a.getTags();//tagIds
        if(StringUtils.isEmpty(tids)){
            return;
        }
        String[] arr=Convert.toStrArray(tids);
        List<CmsTags> tags= Lists.newArrayList();
        for(String tid:arr){
            if (StringUtils.isEmpty(tid)) {
                continue;
            }
            CmsTags tag=tagCache.get(tid);
            if(tag==null){
                tag=tagsMapper.selectCmsTagsByTagId(Long.valueOf(tid));
                tagCache.put(tid,tag);
            }
            tags.add(tag);
        }
        a.setTagList(tags);
    }

    /**
     * 新增文章管理
     *
     * @param cmsArticle 文章管理
     * @return 结果
     */
    @Override
    public int insertCmsArticle(CmsArticle cmsArticle)
    {
//        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
//        Date date = simpleDateFormat.parse(cmsArticle.getCreateTime());
//        cmsArticle.setCreateTime(DateUtils.getNowDate());
        SysUser user = SecurityUtils.getLoginUser().getUser();
        cmsArticle.setYhid(user.getUserId().toString());
        cmsArticle.setDeleted(0);
        cmsArticle.setTopFlag(1);
        cmsArticle.setAvailable(1);
//        cmsArticle.setPublishTime(DateUtils.getTime());
        String tags = cmsArticle.getTags();
        if (StringUtils.isNotEmpty(tags)) { // 判断标签字符串是否不为空
            if (tags.endsWith(",")) { // 如果标签字符串末尾有逗号，则移除逗号
                tags = tags.substring(0, tags.length() - 1);
            }
            cmsArticle.setTags(tags);
        }
        cmsArticle.setAuthor(user.getUserName());

        if (cmsArticle.getCommentFlag() == null) {
            cmsArticle.setCommentFlag(0);
        }
        if ("on".equals(cmsArticle.getCommentFlag())) {
            cmsArticle.setCommentFlag(1);
        }
        if ("off".equals(cmsArticle.getCommentFlag())) {
            cmsArticle.setCommentFlag(0);
        }
        String[] ids = cmsArticle.getIds().split(",");
        try {
            for (String id:ids){
                CmsArticle newAticle = new CmsArticle();
                newAticle.setContent(cmsArticle.getContent());
                newAticle.setCategoryId(id);
                newAticle.setTags(cmsArticle.getTags());
                newAticle.setTitle(cmsArticle.getTitle());
                newAticle.setAuthor(cmsArticle.getAuthor());
                newAticle.setDescription(cmsArticle.getDescription());
                newAticle.setYhid(user.getUserId().toString());
                newAticle.setDeleted(0);
                newAticle.setTopFlag(1);
                newAticle.setAvailable(1);
//                newAticle.setPublishTime(DateUtils.getTime());
                newAticle.setCreateTime(cmsArticle.getCreateTime());
                newAticle.setCoverImage(cmsArticle.getCoverImage());
                cmsArticleMapper.insertCmsArticle(newAticle);
                CmsArticleContent cmsArticleContent = new CmsArticleContent();
                cmsArticleContent.setContent(cmsArticle.getContent());
                cmsArticleContent.setId(newAticle.getId().toString());
                int n = contentMapper.insertCmsArticleContent(cmsArticleContent);
                return n;
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return 1;
    }

    /**
     * 修改文章管理
     *
     * @param cmsArticle 文章管理
     * @return 结果
     */
    @Override
    public int updateCmsArticle(CmsArticle cmsArticle)
    {
        cmsArticle.setUpdateTime(DateUtils.getNowDate());
//        if(SecurityUtils.getLoginUser().getUser() != null){
//            SysUser user = SecurityUtils.getLoginUser().getUser();
//            cmsArticle.setYhid(user.getUserId().toString());
//        }
        cmsArticle.setDeleted(0);
        cmsArticle.setTopFlag(1);
        cmsArticle.setAvailable(1);
//        cmsArticle.setCreateTime(DateUtils.getTime());
        cmsArticleMapper.updateCmsArticle(cmsArticle);
        CmsArticleContent cmsArticleContent = contentMapper.selectCmsArticleContentById(String.valueOf(cmsArticle.getId()));
        cmsArticleContent.setContent(cmsArticle.getContent());
        return contentMapper.updateCmsArticleContent(cmsArticleContent);
    }

    /**
     * 批量删除文章管理
     *
     * @param ids 需要删除的文章管理主键
     * @return 结果
     */
    @Override
    public int deleteCmsArticleByIds(Long[] ids)
    {
        return cmsArticleMapper.deleteCmsArticleByIds(ids);
    }

    /**
     * 删除文章管理信息
     *
     * @param id 文章管理主键
     * @return 结果
     */
    @Override
    public int deleteCmsArticleById(Long id)
    {
        return cmsArticleMapper.deleteCmsArticleById(id);
    }
}
