package com.ruoyi.system.service.impl;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.CmsCategoryMapper;
import com.ruoyi.system.domain.CmsCategory;
import com.ruoyi.system.service.ICmsCategoryService;

/**
 * 文章分类管理Service业务层处理
 *
 * @author libao
 * @date 2024-05-09
 */
@Service
public class CmsCategoryServiceImpl implements ICmsCategoryService
{
    @Autowired
    private CmsCategoryMapper cmsCategoryMapper;

    /**
     * 查询文章分类管理
     *
     * @param categoryId 文章分类管理主键
     * @return 文章分类管理
     */
    @Override
    public CmsCategory selectCmsCategoryByCategoryId(Long categoryId)
    {
        return cmsCategoryMapper.selectCmsCategoryByCategoryId(categoryId);
    }

    /**
     * 查询文章分类管理列表
     *
     * @param cmsCategory 文章分类管理
     * @return 文章分类管理
     */
    @Override
    public List<CmsCategory> selectCmsCategoryList(CmsCategory cmsCategory)
    {
        return cmsCategoryMapper.selectCmsCategoryList(cmsCategory);
    }

    /**
     * 新增文章分类管理
     *
     * @param cmsCategory 文章分类管理
     * @return 结果
     */
    @Override
    public int insertCmsCategory(CmsCategory cmsCategory)
    {
        cmsCategory.setCreateTime(DateUtils.getNowDate());
        return cmsCategoryMapper.insertCmsCategory(cmsCategory);
    }

    /**
     * 修改文章分类管理
     *
     * @param cmsCategory 文章分类管理
     * @return 结果
     */
    @Override
    public int updateCmsCategory(CmsCategory cmsCategory)
    {
        cmsCategory.setUpdateTime(DateUtils.getNowDate());
        return cmsCategoryMapper.updateCmsCategory(cmsCategory);
    }

    /**
     * 批量删除文章分类管理
     *
     * @param categoryIds 需要删除的文章分类管理主键
     * @return 结果
     */
    @Override
    public int deleteCmsCategoryByCategoryIds(Long[] categoryIds)
    {
        return cmsCategoryMapper.deleteCmsCategoryByCategoryIds(categoryIds);
    }

    /**
     * 删除文章分类管理信息
     *
     * @param categoryId 文章分类管理主键
     * @return 结果
     */
    @Override
    public int deleteCmsCategoryByCategoryId(Long categoryId)
    {
        return cmsCategoryMapper.deleteCmsCategoryByCategoryId(categoryId);
    }

    /**
     * 栏目菜单结构分类树
     * @return
     */
    @Override
    public List<CmsCategory> listWithTree() {
        // 1、查询所有分类
        List<CmsCategory> categoryList = cmsCategoryMapper.selectCmsCategoryList(null);
        // 2、构建分类id与分类对象的映射关系
        Map<Long, List<CmsCategory>> categoryMap = new HashMap<>();
        for (CmsCategory category : categoryList) {
            Long parentId = category.getParentId();
            // 将 parentId 为 null 转换为 0L，表示根分类
            if (parentId == null) {
                parentId = 0L;
            }
            categoryMap.computeIfAbsent(parentId, k -> new ArrayList<>()).add(category);
        }
        // 3、构建分类树形结构
        List<CmsCategory> rootCategories = categoryMap.get(0L);
        if (rootCategories != null) {
            for (CmsCategory rootCategory : rootCategories) {
                buildCategoryTree(rootCategory, categoryMap);
            }
        }
        return rootCategories;
    }

    /**
     * 递归构建分类树形结构
     */
    private void buildCategoryTree(CmsCategory category, Map<Long, List<CmsCategory>> categoryMap) {
        List<CmsCategory> children = categoryMap.get(category.getCategoryId());
        if (children != null) {
            for (CmsCategory child : children) {
                buildCategoryTree(child, categoryMap);
            }
        }
        category.setCategory(children);
    }
}
